==> jc-1.4.0.tar.gz: gnu/java/security/provider/GnuRSAPublicKey.h <==
// class gnu.java.security.provider.GnuRSAPublicKey

// class file dependencies
// @dep_class e0fc49206615a798 gnu_java_security_provider_GnuRSAPublicKey
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_security_provider_GnuRSAPublicKey_H_
#define _JC_gnu_java_security_provider_GnuRSAPublicKey_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_math_BigInteger$object;
struct _jc_java_security_spec_RSAPublicKeySpec$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_GnuRSAPublicKey$sub_refs	_jc_gnu_java_security_provider_GnuRSAPublicKey$sub_refs;
typedef struct _jc_gnu_java_security_provider_GnuRSAPublicKey$sub_nonrefs	_jc_gnu_java_security_provider_GnuRSAPublicKey$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_GnuRSAPublicKey$refs	_jc_gnu_java_security_provider_GnuRSAPublicKey$refs;
typedef struct _jc_gnu_java_security_provider_GnuRSAPublicKey$nonrefs	_jc_gnu_java_security_provider_GnuRSAPublicKey$nonrefs;
typedef struct _jc_gnu_java_security_provider_GnuRSAPublicKey$object	_jc_gnu_java_security_provider_GnuRSAPublicKey$object;

typedef const struct _jc_gnu_java_security_provider_GnuRSAPublicKey$vmethods	_jc_gnu_java_security_provider_GnuRSAPublicKey$vmethods;
typedef const struct _jc_gnu_java_security_provider_GnuRSAPublicKey$vtable	_jc_gnu_java_security_provider_GnuRSAPublicKey$vtable;
typedef const struct _jc_gnu_java_security_provider_GnuRSAPublicKey$vtype	_jc_gnu_java_security_provider_GnuRSAPublicKey$vtype;

// Constructors
extern void _jc_gnu_java_security_provider_GnuRSAPublicKey$method$_init$ecf91691c2c729f6(_jc_env *, struct _jc_gnu_java_security_provider_GnuRSAPublicKey$object *, struct _jc_java_security_spec_RSAPublicKeySpec$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_provider_GnuRSAPublicKey$method$getAlgorithm$19abbbc132b9063a(_jc_env *, struct _jc_gnu_java_security_provider_GnuRSAPublicKey$object *);
extern _jc_byte_array *_jc_gnu_java_security_provider_GnuRSAPublicKey$method$getEncoded$eaf136136217eb89(_jc_env *, struct _jc_gnu_java_security_provider_GnuRSAPublicKey$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_provider_GnuRSAPublicKey$method$getFormat$10e2c7b1e3bfcc3b(_jc_env *, struct _jc_gnu_java_security_provider_GnuRSAPublicKey$object *);
extern struct _jc_java_math_BigInteger$object *_jc_gnu_java_security_provider_GnuRSAPublicKey$method$getModulus$430be9ccecc735d2(_jc_env *, struct _jc_gnu_java_security_provider_GnuRSAPublicKey$object *);
extern struct _jc_java_math_BigInteger$object *_jc_gnu_java_security_provider_GnuRSAPublicKey$method$getPublicExponent$6a90dc2525ab30b7(_jc_env *, struct _jc_gnu_java_security_provider_GnuRSAPublicKey$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_provider_GnuRSAPublicKey$method_info$getAlgorithm$19abbbc132b9063a;
extern _jc_method _jc_gnu_java_security_provider_GnuRSAPublicKey$method_info$getEncoded$eaf136136217eb89;
extern _jc_method _jc_gnu_java_security_provider_GnuRSAPublicKey$method_info$getFormat$10e2c7b1e3bfcc3b;
extern _jc_method _jc_gnu_java_security_provider_GnuRSAPublicKey$method_info$getModulus$430be9ccecc735d2;
extern _jc_method _jc_gnu_java_security_provider_GnuRSAPublicKey$method_info$getPublicExponent$6a90dc2525ab30b7;

// Virtual methods structure
struct _jc_gnu_java_security_provider_GnuRSAPublicKey$vmethods {
	struct _jc_java_lang_String$object	*(*getAlgorithm$19abbbc132b9063a)(_jc_env *, struct _jc_gnu_java_security_provider_GnuRSAPublicKey$object *);
	_jc_byte_array	*(*getEncoded$eaf136136217eb89)(_jc_env *, struct _jc_gnu_java_security_provider_GnuRSAPublicKey$object *);
	struct _jc_java_lang_String$object	*(*getFormat$10e2c7b1e3bfcc3b)(_jc_env *, struct _jc_gnu_java_security_provider_GnuRSAPublicKey$object *);
	struct _jc_java_math_BigInteger$object	*(*getModulus$430be9ccecc735d2)(_jc_env *, struct _jc_gnu_java_security_provider_GnuRSAPublicKey$object *);
	struct _jc_java_math_BigInteger$object	*(*getPublicExponent$6a90dc2525ab30b7)(_jc_env *, struct _jc_gnu_java_security_provider_GnuRSAPublicKey$object *);
};

// Vtable
struct _jc_gnu_java_security_provider_GnuRSAPublicKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_provider_GnuRSAPublicKey$vmethods	gnu_java_security_provider_GnuRSAPublicKey;
};

// Vtype
struct _jc_gnu_java_security_provider_GnuRSAPublicKey$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_GnuRSAPublicKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_GnuRSAPublicKey$sub_refs {
	struct _jc_java_security_spec_RSAPublicKeySpec$object	*spec;
	_jc_byte_array	*encodedKey;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_GnuRSAPublicKey$refs {
    _jc_gnu_java_security_provider_GnuRSAPublicKey$sub_refs	gnu_java_security_provider_GnuRSAPublicKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_GnuRSAPublicKey$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_GnuRSAPublicKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_provider_GnuRSAPublicKey$sub_nonrefs	gnu_java_security_provider_GnuRSAPublicKey;
};

// Object instance structure
struct _jc_gnu_java_security_provider_GnuRSAPublicKey$object {
	_jc_gnu_java_security_provider_GnuRSAPublicKey$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_GnuRSAPublicKey$vtype	*vtype;
	_jc_gnu_java_security_provider_GnuRSAPublicKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_GnuRSAPublicKey$vtype _jc_gnu_java_security_provider_GnuRSAPublicKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_GnuRSAPublicKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_GnuRSAPublicKey$class_object;

#endif	/* _JC_gnu_java_security_provider_GnuRSAPublicKey_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/provider/GnuRSAPublicKey.h <==
// class gnu.java.security.provider.GnuRSAPublicKey

// class file dependencies
// @dep_class e0fc49206615a798 gnu_java_security_provider_GnuRSAPublicKey
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_security_provider_GnuRSAPublicKey_H_
#define _JC_gnu_java_security_provider_GnuRSAPublicKey_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_math_BigInteger$object;
struct _jc_java_security_spec_RSAPublicKeySpec$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_GnuRSAPublicKey$sub_refs	_jc_gnu_java_security_provider_GnuRSAPublicKey$sub_refs;
typedef struct _jc_gnu_java_security_provider_GnuRSAPublicKey$sub_nonrefs	_jc_gnu_java_security_provider_GnuRSAPublicKey$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_GnuRSAPublicKey$refs	_jc_gnu_java_security_provider_GnuRSAPublicKey$refs;
typedef struct _jc_gnu_java_security_provider_GnuRSAPublicKey$nonrefs	_jc_gnu_java_security_provider_GnuRSAPublicKey$nonrefs;
typedef struct _jc_gnu_java_security_provider_GnuRSAPublicKey$object	_jc_gnu_java_security_provider_GnuRSAPublicKey$object;

typedef const struct _jc_gnu_java_security_provider_GnuRSAPublicKey$vmethods	_jc_gnu_java_security_provider_GnuRSAPublicKey$vmethods;
typedef const struct _jc_gnu_java_security_provider_GnuRSAPublicKey$vtable	_jc_gnu_java_security_provider_GnuRSAPublicKey$vtable;
typedef const struct _jc_gnu_java_security_provider_GnuRSAPublicKey$vtype	_jc_gnu_java_security_provider_GnuRSAPublicKey$vtype;

// Constructors
extern void _jc_gnu_java_security_provider_GnuRSAPublicKey$method$_init$ecf91691c2c729f6(_jc_env *, struct _jc_gnu_java_security_provider_GnuRSAPublicKey$object *, struct _jc_java_security_spec_RSAPublicKeySpec$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_provider_GnuRSAPublicKey$method$getAlgorithm$19abbbc132b9063a(_jc_env *, struct _jc_gnu_java_security_provider_GnuRSAPublicKey$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_gnu_java_security_provider_GnuRSAPublicKey$method$getEncoded$eaf136136217eb89(_jc_env *, struct _jc_gnu_java_security_provider_GnuRSAPublicKey$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_provider_GnuRSAPublicKey$method$getFormat$10e2c7b1e3bfcc3b(_jc_env *, struct _jc_gnu_java_security_provider_GnuRSAPublicKey$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_gnu_java_security_provider_GnuRSAPublicKey$method$getModulus$430be9ccecc735d2(_jc_env *, struct _jc_gnu_java_security_provider_GnuRSAPublicKey$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_gnu_java_security_provider_GnuRSAPublicKey$method$getPublicExponent$6a90dc2525ab30b7(_jc_env *, struct _jc_gnu_java_security_provider_GnuRSAPublicKey$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_provider_GnuRSAPublicKey$method_info$getAlgorithm$19abbbc132b9063a;
extern _jc_method _jc_gnu_java_security_provider_GnuRSAPublicKey$method_info$getEncoded$eaf136136217eb89;
extern _jc_method _jc_gnu_java_security_provider_GnuRSAPublicKey$method_info$getFormat$10e2c7b1e3bfcc3b;
extern _jc_method _jc_gnu_java_security_provider_GnuRSAPublicKey$method_info$getModulus$430be9ccecc735d2;
extern _jc_method _jc_gnu_java_security_provider_GnuRSAPublicKey$method_info$getPublicExponent$6a90dc2525ab30b7;

// Virtual methods structure
struct _jc_gnu_java_security_provider_GnuRSAPublicKey$vmethods {
	struct _jc_java_lang_String$object	*(*getAlgorithm$19abbbc132b9063a)(_jc_env *, struct _jc_gnu_java_security_provider_GnuRSAPublicKey$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getEncoded$eaf136136217eb89)(_jc_env *, struct _jc_gnu_java_security_provider_GnuRSAPublicKey$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getFormat$10e2c7b1e3bfcc3b)(_jc_env *, struct _jc_gnu_java_security_provider_GnuRSAPublicKey$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getModulus$430be9ccecc735d2)(_jc_env *, struct _jc_gnu_java_security_provider_GnuRSAPublicKey$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getPublicExponent$6a90dc2525ab30b7)(_jc_env *, struct _jc_gnu_java_security_provider_GnuRSAPublicKey$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_provider_GnuRSAPublicKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_provider_GnuRSAPublicKey$vmethods	gnu_java_security_provider_GnuRSAPublicKey;
};

// Vtype
struct _jc_gnu_java_security_provider_GnuRSAPublicKey$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_GnuRSAPublicKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_GnuRSAPublicKey$sub_refs {
	struct _jc_java_security_spec_RSAPublicKeySpec$object	*spec;
	_jc_byte_array	*encodedKey;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_GnuRSAPublicKey$refs {
    _jc_gnu_java_security_provider_GnuRSAPublicKey$sub_refs	gnu_java_security_provider_GnuRSAPublicKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_GnuRSAPublicKey$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_GnuRSAPublicKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_provider_GnuRSAPublicKey$sub_nonrefs	gnu_java_security_provider_GnuRSAPublicKey;
};

// Object instance structure
struct _jc_gnu_java_security_provider_GnuRSAPublicKey$object {
	_jc_gnu_java_security_provider_GnuRSAPublicKey$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_GnuRSAPublicKey$vtype	*vtype;
	_jc_gnu_java_security_provider_GnuRSAPublicKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_GnuRSAPublicKey$vtype _jc_gnu_java_security_provider_GnuRSAPublicKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_GnuRSAPublicKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_GnuRSAPublicKey$class_object;

#endif	/* _JC_gnu_java_security_provider_GnuRSAPublicKey_H_ */
